#!/usr/bin/env node
"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const yargs_1 = __importDefault(require("yargs"));
const helpers_1 = require("yargs/helpers");
const generate_1 = __importDefault(require("./generate"));
const getConfigFile_1 = require("./utils/getConfigFile/getConfigFile");
(0, yargs_1.default)((0, helpers_1.hideBin)(process.argv))
    .command('generate [configPath]', 'Generate hooks', (yargs) => {
    return yargs
        .positional('configPath', {
        describe: 'Path to the configuration file',
        type: 'string',
    })
        .options({
        outputPath: { type: 'string' },
        prettierConfigPath: { type: 'string' },
        relativeSupabasePath: { type: 'string' },
        supabaseExportName: { type: 'string' },
        typesPath: { type: 'string' },
    })
        .check((argv) => {
        if (!argv.configPath && (!argv.outputPath || !argv.typesPath)) {
            throw new Error('When "configPath" is not provided, both "outputPath" and "typesPath" must be provided.');
        }
        return true;
    });
}, async (argv) => {
    const config = argv.configPath
        ? (0, getConfigFile_1.getConfigFile)(argv.configPath)
        : argv;
    await (0, generate_1.default)(config);
})
    .help()
    .alias('help', 'h')
    .strict()
    .parse();
