"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.generateHooks = void 0;
const toTypeName_1 = require("../generateTypes/toTypeName");
const toHookName_1 = require("./toHookName");
function generateHooks({ supabaseExportName, tableName, }) {
    const hooks = [];
    const supabase = supabaseExportName || 'supabase';
    const getRowType = (0, toTypeName_1.toTypeName)({ operation: 'Get', tableName });
    const addRowType = (0, toTypeName_1.toTypeName)({ operation: 'Add', tableName });
    const updateRowType = (0, toTypeName_1.toTypeName)({ operation: 'Update', tableName });
    hooks.push(`export function ${(0, toHookName_1.toHookName)({
        operation: 'Get',
        tableName,
    })}(id: string) {
  return useQuery<${getRowType}, Error>(
    ['${tableName}', id],
    async () => {
      const { data, error } = await ${supabase}
        .from('${tableName}')
        .select('*')
        .eq('id', id)
        .single();
      if (error) throw error;
      if (!data) throw new Error('No data found');
      return data as ${getRowType};
    },
    { enabled: !!id }
  );
}`, `export function ${(0, toHookName_1.toHookName)({ operation: 'GetAll', tableName })}() {
  return useQuery<${getRowType}[], Error>(['${tableName}'], async () => {
    const { data, error } = await ${supabase}.from('${tableName}').select();
    if (error) throw error;
    return data as ${getRowType}[];
  });
}`, `export function ${(0, toHookName_1.toHookName)({ operation: 'Add', tableName })}() {
  const queryClient = useQueryClient();
  return useMutation(
    async (item: ${addRowType}) => {
      const { error } = await ${supabase}
        .from('${tableName}')
        .insert(item)
        .single();
      if (error) throw error;
      return null;
    },
    {
      onSuccess: () => {
        queryClient.invalidateQueries('${tableName}');
      },
    }
  );
}`, `export function ${(0, toHookName_1.toHookName)({ operation: 'Update', tableName })}() {
  const queryClient = useQueryClient();
  return useMutation(
    async (item: ${updateRowType}) => {
      const { error } = await ${supabase}
        .from('${tableName}')
        .update(item.changes)
        .eq('id', item.id)
        .single()
      if (error) throw error;
      return null;
    },
    {
      onSuccess: () => {
        queryClient.invalidateQueries('${tableName}');
      },
    }
  );
}`, `export function ${(0, toHookName_1.toHookName)({ operation: 'Delete', tableName })}() {
  const queryClient = useQueryClient();
  return useMutation(
    async (id: string) => {
      const { error} = await ${supabase}
        .from('${tableName}')
        .delete()
        .eq('id', id)
        .single()
      if (error) throw error;
      return null;
    },
    {
      onSuccess: () => {
        queryClient.invalidateQueries('${tableName}');
      }
    }
  );
}`);
    return hooks;
}
exports.generateHooks = generateHooks;
