"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getTablesProperties = void 0;
const ts_morph_1 = require("ts-morph");
function getTablesProperties(typesPath) {
    const project = new ts_morph_1.Project({
        compilerOptions: {
            allowSyntheticDefaultImports: true,
            esModuleInterop: true,
            module: ts_morph_1.ModuleKind.ESNext,
            target: ts_morph_1.ScriptTarget.ESNext,
            strictNullChecks: true,
        },
    });
    const sourceFile = project.addSourceFileAtPath(typesPath);
    // Find the 'Tables' type alias
    const databaseInterface = sourceFile.getInterfaceOrThrow('Database');
    const publicProperty = databaseInterface.getPropertyOrThrow('public');
    const publicType = publicProperty.getType();
    const tablesProperty = publicType
        .getApparentProperties()
        .find((property) => property.getName() === 'Tables');
    if (!tablesProperty) {
        throw new Error('No Tables property found within the Database interface.');
    }
    const tablesType = project
        .getProgram()
        .getTypeChecker()
        .getTypeAtLocation(tablesProperty.getValueDeclarationOrThrow());
    const tablesProperties = tablesType.getProperties();
    if (tablesProperties.length === 0) {
        throw new Error('No tables found within the Tables property.');
    }
    return tablesProperties;
}
exports.getTablesProperties = getTablesProperties;
